@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.Route53RecoveryCluster 1.21.31\nVersion:        "
-        " 1.21.31.post1\nBuilder version: 7.5.7\nDocs:           "
+        "Type annotations for boto3.Route53RecoveryCluster 1.23.0\nVersion:         1.23.0\nBuilder"
+        " version: 7.5.14\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster//\nBoto3"
         " docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster\nOther"
@@ -23,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.21.31.post1")
+    print("1.23.0")
 
 
 def main() -> None:
